fn text_run_position(parent_id: Id, row: usize, column: usize) -> TextPositionExpand description
Convert a (row, column) layout cursor position to a text run node ID and character index, accounting for rows that are split into multiple text runs.
fn text_run_position(parent_id: Id, row: usize, column: usize) -> TextPositionConvert a (row, column) layout cursor position to a text run node ID and character index, accounting for rows that are split into multiple text runs.